package com.pms.ocp.controller;

import com.pms.ocp.biz.BizModelDemandService;
import com.pms.ocp.model.dto.ModelPropertyVersionDemandDTO;
import com.pms.ocp.model.dto.ModelVersionDemandDTO;
import com.pms.ocp.model.vo.ResponseVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @Auther: wangjian
 * @Date: 2022/3/29 17:18
 * @Description:模型库管理管控需求接口
 */

@Slf4j
@RequestMapping("/model-control/v1")
@RestController
@Api(tags = "模型库管理管控需求接口")
public class ModelControlDemandController {

    @Autowired
    private BizModelDemandService bizModelDemandService;

    /**
     * 模型需求-增加
     *
     * @return
     */
    @ApiOperation("模型需求-增加")
    @PostMapping("/create/modelDemand")
    public ResponseVO createModelDemand(@RequestBody ModelVersionDemandDTO modelVersionDemandDTO) {

        return ResponseVO.ok(bizModelDemandService.createModelDemand(modelVersionDemandDTO));
    }

    /**
     * 模型属性需求-增加
     *
     * @return
     */
    @ApiOperation("模型属性需求-增加")
    @PostMapping("/create/modelPropertyDemand")
    public ResponseVO createModelPropertyDemand(@RequestBody ModelPropertyVersionDemandDTO modelPropertyVersionDemandDTO) {

        return ResponseVO.ok(bizModelDemandService.createModelPropertyDemand(modelPropertyVersionDemandDTO));
    }

    /**
     * 模型需求-删除
     *
     * @return
     */
    @ApiOperation("模型需求-删除")
    @PostMapping("/delete/modelDemand")
    public ResponseVO deleteModelDemand(@ApiParam(value = "模型订阅编号") @RequestParam(value = "objId", required = false) String objId,
                                        @ApiParam(value = "模型编码") @RequestParam(value = "modelCode", required = false) String modelCode) {
        return ResponseVO.ok(bizModelDemandService.deleteModelDemand(objId, modelCode));
    }

    /**
     * 模型属性需求-删除
     *
     * @return
     */
    @ApiOperation("模型属性需求-删除")
    @PostMapping("/delete/modelPropertyDemand")
    public ResponseVO deleteModelPropertyDemand(@ApiParam(value = "模型订阅编号") @RequestParam(value = "objId", required = false) String objId,
                                                @ApiParam(value = "模型编码") @RequestParam(value = "modelCode", required = false) String modelCode,
                                                @ApiParam(value = "属性编码") @RequestParam(value = "propCode", required = false) String propCode) {
        return ResponseVO.ok(bizModelDemandService.deleteModelPropertyDemand(objId, modelCode, propCode));
    }

    /**
     * 模型需求-修改
     *
     * @return
     */
    @ApiOperation("模型需求-修改")
    @PostMapping("/update/modelDemand")
    public ResponseVO updateModelDemand(@RequestBody ModelVersionDemandDTO modelVersionDemandDTO) {
        return ResponseVO.ok(bizModelDemandService.updateModelDemand(modelVersionDemandDTO));
    }

    /**
     * 模型属性需求-修改
     *
     * @return
     */
    @ApiOperation("模型属性需求-修改")
    @PostMapping("/update/modelPropertyDemand")
    public ResponseVO updateModelPropertyDemand(@RequestBody ModelPropertyVersionDemandDTO modelPropertyVersionDemandDTO) {
        return ResponseVO.ok(bizModelDemandService.updateModelPropertyDemand(modelPropertyVersionDemandDTO));
    }

    /**
     * 模型需求-查询列表
     *
     * @return
     */
    @ApiOperation("模型需求-查询列表")
    @GetMapping("/get/modelDemand/list")
    public ResponseVO getModelDemandList(@ApiParam(value = "所属级别") @RequestParam(value = "belongLevel", defaultValue = "0") String belongLevel,
                                         @ApiParam(value = "模型分类编码") @RequestParam(value = "modelGroupCode", required = false) String modelGroupCode,
                                         @ApiParam(value = "当前页") @RequestParam(value = "currentPage") Integer currentPage,
                                         @ApiParam(value = "每页数量") @RequestParam(value = "pageSize") Integer pageSize,
                                         @ApiParam(value = "模糊搜索条件") @RequestParam(value = "searchCondition", required = false) String searchCondition) {
        return ResponseVO.ok(bizModelDemandService.getModelDemandList(belongLevel, modelGroupCode, currentPage, pageSize));

    }


    /**
     * 模型属性需求-查询列表
     *
     * @return
     */
    @ApiOperation("模型属性需求-查询列表")
    @GetMapping("/get/modelPropertyDemand/list")
    public ResponseVO getModelPropertyDemandList(@ApiParam(value = "所属级别") @RequestParam(value = "belongLevel", defaultValue = "0") String belongLevel,
                                                 @ApiParam(value = "模型编码") @RequestParam(value = "modelCode", required = false) String modelCode,
                                                 @ApiParam(value = "当前页") @RequestParam(value = "currentPage") Integer currentPage,
                                                 @ApiParam(value = "每页数量") @RequestParam(value = "pageSize") Integer pageSize,
                                                 @ApiParam(value = "模糊搜索条件") @RequestParam(value = "searchCondition", required = false) String searchCondition) {
        return ResponseVO.ok(bizModelDemandService.getModelPropertyDemandList(belongLevel, modelCode, currentPage, pageSize));

    }


}
